@@ -6,10 +6,8 @@
 
 #include "comicdata.h"
 
+#include <KIO/OpenUrlJob>
 #include <KLocalizedString>
-#include <Plasma/Theme>
-// Qt
-#include <QPainter>
 
 ComicData::ComicData()
 {
@@ -24,14 +22,14 @@ void ComicData::init(const QString &id, const KConfigGroup &config)
 
 void ComicData::load()
 {
-    mScaleComic = mCfg.readEntry(QLatin1String("scaleToContent_") + mId, false);
+    mShowActualSize = mCfg.readEntry(QLatin1String("scaleToContent_") + mId, false);
     mMaxStripNum = mCfg.readEntry(QLatin1String("maxStripNum_") + mId, 0);
     mStored = mCfg.readEntry(QLatin1String("storedPosition_") + mId, QString());
 }
 
 void ComicData::save()
 {
-    mCfg.writeEntry(QLatin1String("scaleToContent_") + mId, mScaleComic);
+    mCfg.writeEntry(QLatin1String("scaleToContent_") + mId, mShowActualSize);
     mCfg.writeEntry(QLatin1String("maxStripNum_") + mId, mMaxStripNum);
     mCfg.writeEntry(QLatin1String("storedPosition_") + id(), mStored);
 
@@ -42,9 +40,9 @@ void ComicData::save()
     }
 }
 
-void ComicData::setScaleComic(bool scale)
+void ComicData::setShowActualSize(bool show)
 {
-    mScaleComic = scale;
+    mShowActualSize = show;
     save();
 }
 
@@ -58,12 +56,13 @@ void ComicData::setData(const ComicMetaData &data)
 {
     if (!data.error) {
         mImage = data.image;
-        mPrev = data.previousIdentifier;
-        mNext = data.nextIdentifier;
         mAdditionalText = data.additionalText;
         mReady = true;
     }
 
+    mPrev = data.previousIdentifier;
+    mNext = data.nextIdentifier;
+    mIsError = data.error;
     mWebsiteUrl = data.websiteUrl;
     mImageUrl = data.imageUrl;
     mShopUrl = data.shopUrl;
@@ -102,3 +101,24 @@ void ComicData::setData(const ComicMetaData &data)
 
     save();
 }
+
+bool ComicData::saveImage(const QUrl &fileUrl)
+{
+    if (!fileUrl.isValid()) {
+        return false;
+    }
+
+    return mImage.save(fileUrl.toLocalFile(), "PNG");
+}
+
+void ComicData::launchWebsite()
+{
+    auto *job = new KIO::OpenUrlJob(mWebsiteUrl);
+    job->start();
+}
+
+void ComicData::launchShop()
+{
+    auto *job = new KIO::OpenUrlJob(mShopUrl);
+    job->start();
+}
