@@ -7,29 +7,73 @@
 #ifndef COMIC_DATA_H
 #define COMIC_DATA_H
 
-#include "comicinfo.h"
 #include "engine/types.h"
 
-// Qt
 #include <KConfigGroup>
+
+// Qt
 #include <QImage>
 #include <QString>
 #include <QUrl>
+#include <qqmlregistration.h>
 
 class ComicData
 {
+    Q_GADGET
+    QML_VALUE_TYPE(comicData)
+
+    Q_PROPERTY(Type type READ typeForQml)
+    Q_PROPERTY(QString id READ id)
+    Q_PROPERTY(QImage image READ image)
+    Q_PROPERTY(QString prev READ prev)
+    Q_PROPERTY(QString next READ next)
+    Q_PROPERTY(QString additionalText READ additionalText)
+    Q_PROPERTY(QUrl websiteUrl READ websiteUrl)
+    Q_PROPERTY(QString websiteHost READ websiteHost)
+    Q_PROPERTY(QUrl shopUrl READ shopUrl)
+    Q_PROPERTY(QString first READ first)
+    Q_PROPERTY(bool hasFirst READ hasFirst)
+    Q_PROPERTY(QString stripTitle READ stripTitle)
+    Q_PROPERTY(QString author READ author)
+    Q_PROPERTY(QString title READ title)
+    Q_PROPERTY(QString current READ current)
+    Q_PROPERTY(QString currentReadable READ currentReadable)
+    Q_PROPERTY(int firstStripNum READ firstStripNum)
+    Q_PROPERTY(int maxStripNum READ maxStripNum)
+    Q_PROPERTY(bool isLeftToRight READ isLeftToRight)
+    Q_PROPERTY(bool isTopToBottom READ isTopToBottom)
+    Q_PROPERTY(bool isError READ isError)
+    Q_PROPERTY(bool storePosition READ storePosition)
+    Q_PROPERTY(bool ready READ ready)
+
 public:
+    enum class Type { // redefined for QML access, keep in sync with engine/types.h
+        DateIdentifier,
+        NumberIdentifier,
+        StringIdentifier,
+    };
+    Q_ENUM(Type)
+
     ComicData();
 
     void init(const QString &id, const KConfigGroup &config);
 
     void setData(const ComicMetaData &data);
 
+    Q_INVOKABLE bool saveImage(const QUrl &fileUrl);
+    Q_INVOKABLE void launchShop();
+    Q_INVOKABLE void launchWebsite();
+
     IdentifierType type() const
     {
         return mType;
     }
 
+    Type typeForQml() const
+    {
+        return static_cast<Type>(mType);
+    }
+
     /**
      * The identifier of the comic, e.g. "garfield"
      */
@@ -134,6 +178,11 @@ public:
         return mWebsiteUrl;
     }
 
+    QString websiteHost() const
+    {
+        return mWebsiteUrl.host();
+    }
+
     QUrl imageUrl() const
     {
         return mImageUrl;
@@ -154,9 +203,9 @@ public:
         return mImage;
     }
 
-    bool scaleComic() const
+    bool showActualSize() const
     {
-        return mScaleComic;
+        return mShowActualSize;
     }
 
     bool isLeftToRight() const
@@ -174,12 +223,7 @@ public:
         return !mStored.isEmpty();
     }
 
-    void setScaleComic(bool scale);
-
-    QString errorStrip() const
-    {
-        return mErrorStrip;
-    }
+    void setShowActualSize(bool show);
 
     int firstStripNum() const
     {
@@ -196,6 +240,11 @@ public:
         return mReady;
     }
 
+    bool isError() const
+    {
+        return mIsError;
+    }
+
     void save();
 
 private:
@@ -212,8 +261,6 @@ private:
     QString mStored;
     QString mCurrentReadable;
 
-    QString mErrorStrip;
-
     QString mAuthor;
     QString mTitle;
     QString mStripTitle;
@@ -228,10 +275,11 @@ private:
     int mFirstStripNum = 0;
     int mMaxStripNum = 0;
 
-    bool mScaleComic = false;
+    bool mShowActualSize = false;
     bool mIsLeftToRight = false;
     bool mIsTopToBottom = false;
     bool mReady = false;
+    bool mIsError = false;
 
     KConfigGroup mCfg;
 };
